<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <meta name="description" content="API documentation">
  <meta name="author" content="Nikolajus Krauklis <nikolajus@gmail.com>">

  <title>RESTful api documentation</title>
  <link rel="stylesheet" href="http://netdna.bootstrapcdn.com/bootstrap/3.0.0-rc1/css/bootstrap.min.css">
  <style>
    .label-get { background-color: #5cb85c;}
    .label-post { background-color: #f0ad4e;}
    .label-put { background-color: #5bc0de;}
    .label-delete { background-color: #d9534f;}
    .bs-callout {
        margin: 20px 0;
        padding: 15px 30px 15px 15px;
        border-left: 5px solid #eee;
     }
    .bs-callout-danger {
      background-color: #fcf2f2;
      border-color: #dFb5b4;
    }
  </style>
</head>
<body>
